@@ -5,9 +5,9 @@
 */
 
 #include "articleviewerwebenginepage.h"
+#include "actionmanager.h"
 #include <QWebEngineSettings>
 #include <WebEngineViewer/ZoomActionMenu>
-#include <actionmanager.h>
 
 #include "akregatorconfig.h"
 
@@ -42,7 +42,7 @@ ArticleViewerWebEnginePage::~ArticleViewerWebEnginePage() = default;
 bool ArticleViewerWebEnginePage::acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame)
 {
     Q_UNUSED(type)
-    if (url.scheme() == QLatin1String("data")) {
+    if (url.scheme() == QLatin1StringView("data")) {
         return true;
     }
     if (isMainFrame && type == NavigationTypeLinkClicked) {
